summaryrefslogtreecommitdiffstats
path: root/chrome/browser/google_apis/gdata_wapi_parser.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/google_apis/gdata_wapi_parser.h')
-rw-r--r--chrome/browser/google_apis/gdata_wapi_parser.h42
1 files changed, 21 insertions, 21 deletions
diff --git a/chrome/browser/google_apis/gdata_wapi_parser.h b/chrome/browser/google_apis/gdata_wapi_parser.h
index 99395e1..20c3e56 100644
--- a/chrome/browser/google_apis/gdata_wapi_parser.h
+++ b/chrome/browser/google_apis/gdata_wapi_parser.h
@@ -100,7 +100,7 @@ class Link {
const std::string& mime_type() const { return mime_type_; }
private:
- friend class DocumentEntry;
+ friend class ResourceEntry;
// Converts value of link.rel into LinkType. Outputs to |type| and returns
// true when |rel| has a valid value. Otherwise does nothing and returns
// false.
@@ -145,7 +145,7 @@ class FeedLink {
const GURL& href() const { return href_; }
private:
- friend class DocumentEntry;
+ friend class ResourceEntry;
// Converts value of gd$feedLink.rel into FeedLinkType enum.
// Outputs to |result| and returns true when |rel| has a valid
// value. Otherwise does nothing and returns false.
@@ -175,7 +175,7 @@ class Author {
const std::string& email() const { return email_; }
private:
- friend class DocumentEntry;
+ friend class ResourceEntry;
string16 name_;
std::string email_;
@@ -212,7 +212,7 @@ class Category {
const std::string& term() const { return term_; }
private:
- friend class DocumentEntry;
+ friend class ResourceEntry;
// Converts category scheme into CategoryType enum. For example,
// http://schemas.google.com/g/2005#kind => Category::CATEGORY_KIND
// Returns false and does not change |result| when |scheme| has an
@@ -243,7 +243,7 @@ class Content {
const std::string& mime_type() const { return mime_type_; }
private:
- friend class DocumentEntry;
+ friend class ResourceEntry;
GURL url_;
std::string mime_type_;
@@ -338,9 +338,9 @@ class FeedEntry {
};
// Document feed entry.
-class DocumentEntry : public FeedEntry {
+class ResourceEntry : public FeedEntry {
public:
- virtual ~DocumentEntry();
+ virtual ~ResourceEntry();
// Extracts "entry" dictionary from the JSON value, and parse the contents,
// using CreateFrom(). Returns NULL on failure. The input JSON data, coming
@@ -353,25 +353,25 @@ class DocumentEntry : public FeedEntry {
// }
//
// The caller should delete the returned object.
- static scoped_ptr<DocumentEntry> ExtractAndParse(const base::Value& value);
+ static scoped_ptr<ResourceEntry> ExtractAndParse(const base::Value& value);
// Creates document entry from parsed JSON Value. You should call
// this instead of instantiating JSONValueConverter by yourself
// because this method does some post-process for some fields. See
// FillRemainingFields comment and implementation for the details.
- static scoped_ptr<DocumentEntry> CreateFrom(const base::Value& value);
+ static scoped_ptr<ResourceEntry> CreateFrom(const base::Value& value);
// Creates document entry from parsed XML.
- static scoped_ptr<DocumentEntry> CreateFromXml(XmlReader* xml_reader);
+ static scoped_ptr<ResourceEntry> CreateFromXml(XmlReader* xml_reader);
// Creates document entry from FileResource.
// TODO(kochi): This should go away soon. http://crbug.com/142293
- static scoped_ptr<DocumentEntry> CreateFromFileResource(
+ static scoped_ptr<ResourceEntry> CreateFromFileResource(
const FileResource& file);
// Creates document entry from ChangeResource.
// Todo(Kochi): This should go away soon. http://crbug.com/142293
- static scoped_ptr<DocumentEntry> CreateFromChangeResource(
+ static scoped_ptr<ResourceEntry> CreateFromChangeResource(
const ChangeResource& change);
// Returns name of entry node.
@@ -380,7 +380,7 @@ class DocumentEntry : public FeedEntry {
// Registers the mapping between JSON field names and the members in
// this class.
static void RegisterJSONConverter(
- base::JSONValueConverter<DocumentEntry>* converter);
+ base::JSONValueConverter<ResourceEntry>* converter);
// Sets true to |result| if the field exists.
// Always returns true even when the field does not exist.
@@ -495,11 +495,11 @@ class DocumentEntry : public FeedEntry {
static int ClassifyEntryKind(DriveEntryKind kind);
private:
- friend class base::internal::RepeatedMessageConverter<DocumentEntry>;
+ friend class base::internal::RepeatedMessageConverter<ResourceEntry>;
friend class DocumentFeed;
friend class ResumeUploadOperation;
- DocumentEntry();
+ ResourceEntry();
// Fills the remaining fields where JSONValueConverter cannot catch.
void FillRemainingFields();
@@ -528,7 +528,7 @@ class DocumentEntry : public FeedEntry {
bool removed_;
int64 changestamp_;
- DISALLOW_COPY_AND_ASSIGN(DocumentEntry);
+ DISALLOW_COPY_AND_ASSIGN(ResourceEntry);
};
// Document feed represents a list of entries. The feed is paginated and
@@ -552,7 +552,7 @@ class DocumentFeed : public FeedEntry {
// Creates feed from parsed JSON Value. You should call this
// instead of instantiating JSONValueConverter by yourself because
// this method does some post-process for some fields. See
// FillRemainingFields comment and implementation in DocumentEntry
// class for the details.
static scoped_ptr<DocumentFeed> CreateFrom(const base::Value& value);
// Variant of CreateFrom() above, creates feed from parsed ChangeList.
@@ -570,11 +570,11 @@ class DocumentFeed : public FeedEntry {
bool GetNextFeedURL(GURL* url) const;
// List of document entries.
- const ScopedVector<DocumentEntry>& entries() const { return entries_; }
+ const ScopedVector<ResourceEntry>& entries() const { return entries_; }
// Releases entries_ into |entries|. This is a transfer of ownership, so the
// caller is responsible for deleting the elements of |entries|.
- void ReleaseEntries(std::vector<DocumentEntry*>* entries);
+ void ReleaseEntries(std::vector<ResourceEntry*>* entries);
// Start index of the document entry list.
int start_index() const { return start_index_; }
@@ -596,7 +596,7 @@ class DocumentFeed : public FeedEntry {
// Return false if parsing fails.
bool Parse(const base::Value& value);
- ScopedVector<DocumentEntry> entries_;
+ ScopedVector<ResourceEntry> entries_;
int start_index_;
int items_per_page_;
std::string title_;
@@ -700,7 +700,7 @@ class AccountMetadataFeed {
// Creates feed from parsed JSON Value. You should call this
// instead of instantiating JSONValueConverter by yourself because
// this method does some post-process for some fields. See
// FillRemainingFields comment and implementation in DocumentEntry
// class for the details.
static scoped_ptr<AccountMetadataFeed> CreateFrom(const base::Value& value);
@@ -552,7 +552,7 @@ class DocumentFeed : public FeedEntry {
// instead of instantiating JSONValueConverter by yourself because
// this method does some post-process for some fields. See
- // FillRemainingFields comment and implementation in DocumentEntry
+ // FillRemainingFields comment and implementation in ResourceEntry
// class for the details.
static scoped_ptr<DocumentFeed> CreateFrom(const base::Value& value);
@@ -700,7 +700,7 @@ class AccountMetadataFeed {
// instead of instantiating JSONValueConverter by yourself because
// this method does some post-process for some fields. See
- // FillRemainingFields comment and implementation in DocumentEntry
+ // FillRemainingFields comment and implementation in ResourceEntry
// class for the details.
static scoped_ptr<AccountMetadataFeed> CreateFrom(const base::Value& value);